#!/usr/bin/env python3
from jira import JIRA
import configparser


# get config
config = configparser.ConfigParser()
config.read('login.ini')
jconf = config['jira']

# get jira
jira = JIRA(basic_auth=(jconf['login'], jconf['password']), options={'server': "https://pixers.atlassian.net"})

# compile query
transition_states = [
    # "Do kodowania",
    "Kodowanie",
    "In Review",
    "Testowanie",
    "In Progress",
    "Do wdrożenia",
    "Done",
    "Zakończone"
]

states_done = [
    "Do wdrożenia",
    # "Wdrożone",
    "Wdrożenie czeka",
    "Zakończone",
    "Done",
]

filters = " OR ".join(f"status changed to \"{status}\" by currentUser()" for status in transition_states)

state_is_done = " OR ".join(f"status = \"{status}\"" for status in states_done)

query_closed = f"updated > startOfMonth() AND ({state_is_done}) AND ({filters} OR assignee = currentUser()) ORDER BY updated DESC"
query_open = f"updated > startOfMonth() AND NOT ({state_is_done}) AND ({filters} OR assignee = currentUser()) ORDER BY updated DESC"


def jiraprint(querry):
    issues = jira.search_issues(querry)
    for issue in issues:
        options = []
        if issue.fields.priority.name != "Minor":
            options.append(issue.fields.priority.name)

        if issue.fields.issuetype.name != "Task":
            options.append(issue.fields.issuetype.name)

        if len(options):
            optional = " (" + ", ".join(options) + ")"
        else:
            optional = ""

        print(f"  - {issue}{optional} [{issue.fields.status}]: {issue.fields.summary}")


print("Udało się:")
jiraprint(query_closed)

print("\nW trakcie:")
jiraprint(query_open)
